@@ -6,13 +6,12 @@ from jwpackage.authentication.exceptions import *
 import time
 from datetime import datetime
 class Authenticator():
-    def __init__(self,public_key,token,request):
+    def __init__(self,public_key,token,request=None):
         self.request = request
         self.public_key = serialization.load_pem_public_key(
             public_key,
             backend=default_backend()
         )
-        print("public key",self.public_key)
         try:
             self.data = jwt.decode(token, public_key,algorithms=["RS256"],audience="justwicks")
             self.auth = True
